class Garen::Client
  def initialize(params = {})
    @api_key          = params[:api_key] || Garen.configuration.api_key
    @service_platform = params[:service_platform] || 'na1'
    @debug            = params[:debug].present? ? :logger : :raise_error

    raise ArgumentError, 'Riot API Key Required' unless @api_key.present?
    @conn = create_connection
  end

  def create_connection
    Faraday.new(url: "https://#{@service_platform.downcase}.api.riotgames.com") do |f|
      f.headers['X-Riot-Token'] = @api_key
      f.headers['Accept'] = 'application/json'
      f.headers['User-Agent'] = "Garen api gem #{Garen::VERSION}"

      f.request :url_encoded

      f.response :rashify
      f.response :json
      f.response @debug

      f.adapter Faraday.default_adapter
    end
  end

  def champion
    Garen::Champion.new(@conn)
  end

  def champion_mastery
    Garen::ChampionMastery.new(@conn)
  end

  def league
    Garen::League.new(@conn)
  end

  def masteries
    Garen::Masteries.new(@conn)
  end

  def match
    Garen::Match.new(@conn)
  end

  def runes
    Garen::Runes.new(@conn)
  end

  def spectator
    Garen::Spectator.new(@conn)
  end

  def static
    Garen::Static.new(@conn)
  end

  def status
    Garen::Status.new(@conn)
  end

  def summoner
    Garen::Summoner.new(@conn)
  end
end
